# ======================================================================
# Define options
# ======================================================================

set opt(chan)           Channel/WirelessChannel    ;# channel type
set opt(prop)           Propagation/TwoRayGround   ;# radio-propagation model
set opt(netif)          Phy/WirelessPhy            ;# network interface type
set opt(mac)            Mac/802_11                 ;# MAC type
set opt(ifq)            Queue/DropTail/PriQueue    ;# interface queue type
set opt(ll)             LL                         ;# link layer type
set opt(ant)            Antenna/OmniAntenna        ;# antenna model
set opt(ifqlen)         20                         ;# max packet in ifq
set opt(nn)             1                          ;# number of mobilenodes
set opt(adhocRouting)   DSDV	                   ;# routing protocol

set opt(x)      100                            ;# x coordinate of topology
set opt(y)      100                            ;# y coordinate of topology
set opt(duration)   4000.0                       ;# duration of simulation
set opt(startmin) 0.1
set opt(startmax) 0.3
Agent/DSDV set fulltcp_ 1					   ;# Required by fullTCP
#######################################
# Generate Random number
#######################################
set startrng [new RNG]
set positionrng [new RNG]
set rvstart [new RandomVariable/Uniform]
$rvstart set min_ $opt(startmin)
$rvstart set max_ $opt(startmax)
$rvstart use-rng $startrng
set rvposition [new RandomVariable/Uniform]
$rvposition set min_ 0
$rvposition set max_ $opt(x)
$rvposition use-rng $positionrng
set opt(start) [$rvstart value]
set opt(stop) [expr $opt(start) + $opt(duration)]

# create simulator instance
set ns   [new Simulator]
$ns use-newtrace
###############################
# Global allocations
###############################
set topo      [new Topography]
$topo load_flatgrid $opt(x) $opt(y)

set god       [create-god [expr $opt(nn) + 1]]

set tracefd  [open ${argv0}.tr w]
set namtrace [open ${argv0}.nam w]
$ns trace-all $tracefd
$ns namtrace-all-wireless $namtrace $opt(x) $opt(y)


# configure for base-station node
$ns node-config -mobileIP ON \
                -adhocRouting $opt(adhocRouting) \
                -llType $opt(ll) \
                -macType $opt(mac) \
                -ifqType $opt(ifq) \
                -ifqLen $opt(ifqlen) \
                -antType $opt(ant) \
				-propType $opt(prop) \
                -phyType $opt(netif) \
                -channel [new $opt(chan)] \
				-topoInstance $topo \
                -wiredRouting OFF \
				-agentTrace ON \
                -routerTrace OFF \
                -macTrace OFF 

# configure AP
set AP  [$ns node]
$AP random-motion 0
$AP set X_ 1
$AP set Y_ 2
$AP set Z_ 0
# output to screen
set xstr [format "%7.4f" [$AP set X_]]
set ystr [format "%7.4f" [$AP set Y_]]
puts " AP is at   X = $xstr   Y = $ystr "
# configure user
for {set i 0} {$i < $opt(nn)} {incr i} {
    set n($i)  [$ns node]
	$n($i) random-motion 0
	$n($i) set X_ [$rvposition value]
    $n($i) set Y_ [$rvposition value]
    $n($i) set Z_ 0
    # output to screen
    set xstr [format "%7.4f" [$n($i) set X_]]
    set ystr [format "%7.4f" [$n($i) set Y_]]
    puts " node $i is at   X = $xstr   Y = $ystr "
}

# setup TCP connections
set tcp [new Agent/TCP/FullTcp]
$tcp set class_ 2
$tcp set pipectrl_ 1
#$tcp set packetSize_ 1500
$tcp set segsize_ 1426
set sink [new Agent/TCP/FullTcp]
$ns attach-agent $AP $tcp
$ns attach-agent $n(0) $sink

$ns connect $tcp $sink
$sink listen
set tfile [new FreeTracefile]
$tfile filename http1.tt
set tt [new Application/Traffic/FreeTrace]
$tt attach-tracefile $tfile
$tt attach-agent $tcp
$ns at  $opt(start) "$tt start"
$ns at  $opt(stop) "$tt stop"

$ns at [expr $opt(stop) + 0.5] "stop"
$ns at [expr $opt(stop) + 0.6] "puts \"NS EXITING...\" ; $ns halt"

proc stop {} {
    global ns tracefd namtrace
    $ns flush-trace
    close $tracefd
    close $namtrace
}

puts "Starting Simulation..."
$ns run

